MinimalEnergyClustering: Minimal Energy Clustering

View source: R/MinimalEnergyClustering.R

MinimalEnergyClusteringR Documentation

Minimal Energy Clustering

Description

Hierchical Clustering using the minimal energy approach of [Szekely/Rizzo, 2005].

Usage

MinimalEnergyClustering(DataOrDistances, ClusterNo = 0,

ColorTreshold = 0,

DistanceMethod="euclidean", Data,PlotIt=FALSE,...)

Arguments

DataOrDistances

[1:n,1:d] matrix containing the dataset to be clustered. It consists of n cases of d-dimensional data points. Every case has d attributes, variables or features. Alternatively, symmetric [1:n,1:n] distance matrix

ClusterNo

A number k which defines k different clusters to be build by the algorithm.

DistanceMethod

See parDist, for example 'euclidean','mahalanobis','manhatten' (cityblock),'fJaccard','binary', 'canberra', 'maximum'. Any unambiguous substring can be given.

ColorTreshold

Draws cutline w.r.t. dendrogram y-axis (height), height of line as scalar should be given

Data

[1:n,1:d] data matrix in the case that DataOrDistances is missing and partial matching does not work.

PlotIt

If TRUE and ClusterNo>0 plots dendrogram using ClusterDendrogram

If TRUE and ClusterNo==0 plots black dendrogram using base R plot

FALSE: No plot

...

In case of plotting further argument for plot, see as.dendrogram

Value

List of

Cls

If ClusterNo>0: [1:n] numerical vector with n numbers defining the classification as the main output of the clustering algorithm. It has k unique numbers representing the arbitrary labels of the clustering. Otherwise ClusterNo=0: NULL

Dendrogram

Dendrogram of hierarchical clustering algorithm

Object

Ultrametric tree of hierarchical clustering algorithm

Author(s)

Michael Thrun

References

[Szekely/Rizzo, 2005] Szekely, G. J. and Rizzo, M. L.: Hierarchical Clustering via Joint Between-Within Distances: Extending Ward's Minimum Variance Method, Journal of Classification, 22(2) 151-183.http://dx.doi.org/10.1007/s00357-005-0012-9, 2005.

See Also

HierarchicalClustering

Examples

data('Hepta')
out=MinimalEnergyClustering(Hepta$Data,ClusterNo=7)

FCPS documentation built on Oct. 3, 2026, 9:06 a.m.