RobustTrimmedClustering: Robust Trimmed Clustering

View source: R/RobustTrimmedClustering.R

RobustTrimmedClusteringR Documentation

Robust Trimmed Clustering

Description

Robust Trimmed Clustering invented by [Garcia-Escudero et al., 2008] and implemented by [Fritz et al., 2012].

Usage

RobustTrimmedClustering(Data, ClusterNo,

Alpha=0.05,PlotIt=FALSE,...)

Arguments

Data

[1:n,1:d] matrix containing the dataset to be clustered. It consists of n cases of d-dimensional data points. Every case has d attributes, variables or features.

ClusterNo

A number k which defines k different clusters to be built by the algorithm.

PlotIt

Default: FALSE, if TRUE plots the first three dimensions of the dataset with colored three-dimensional data points defined by the clustering stored in Cls

Alpha

If alpha = 0, no trimming is performed. Otherwise, this is the proportion of data points to trim. tclust uses 0.05 by default.

...

Further arguments passed to tclust, such as niter1 (number of random initializations), niter2 (maximum number of concentration steps), restr, and restr.fact.

Details

The algorithm initializes k clusters randomly and performs concentration steps to improve the current cluster assignment. The maximum number of concentration steps is controlled by iter.max. The procedure is initialized nstart times and continues until convergence or until iter.max is reached. More complex datasets may require larger values of nstart and iter.max, which increases computation time. Larger values of restr.fact allow greater heterogeneity among cluster scatter matrices, whereas values near 1 impose similar scatter. The constraint type restr can be set to "eigen", "deter", or "sigma". See tclust and [Fritz et al., 2012] for details.

Value

List of

Cls

[1:n] numerical vector with n numbers defining the classification as the main output of the clustering algorithm. It has k unique numbers representing the arbitrary labels of the clustering.

Object

Object defined by clustering algorithm as the other output of this algorithm

Author(s)

Michael Thrun

References

[Garcia-Escudero et al., 2008] Garcia-Escudero, L. A., Gordaliza, A., Matran, C., & Mayo-Iscar, A.: A general trimming approach to robust cluster analysis, The annals of Statistics, Vol. 36(3), pp. 1324-1345. 2008.

[Fritz et al., 2012] Fritz, H., Garcia-Escudero, L. A., & Mayo-Iscar, A.: tclust: An R package for a trimming approach to cluster analysis, Journal of statistical Software, Vol. 47(12), pp. 1-26. 2012.

Examples




data("Hepta")
out <- RobustTrimmedClustering(
  Hepta$Data,
  ClusterNo = 7,
  Alpha = 0,
  PlotIt = FALSE
)


FCPS documentation built on Oct. 3, 2026, 9:06 a.m.